@@ -79,7 +79,7 @@ make_progression_handler <- function(name, reporter = list(), handler = NULL, en
   }
 
   ## Reporter
-  for (key in setdiff(c("reset", "initiate", "update", "finish", "hide", "unhide"), names(reporter))) {
+  for (key in setdiff(c("reset", "initiate", "update", "finish", "hide", "unhide", "interrupt"), names(reporter))) {
     reporter[[key]] <- structure(function(...) NULL, class = "null_function")
   }
 
@@ -243,6 +243,23 @@ make_progression_handler <- function(name, reporter = list(), handler = NULL, en
     if (debug) mprintf("unhide_reporter() ... done")
   }
 
+  interrupt_reporter <- function(p) {
+    args <- reporter_args(progression = p)
+    debug <- getOption("progressr.debug", FALSE)
+    if (debug) {
+      mprintf("interrupt_reporter() ...")
+      mstr(args)
+    }
+#    stop_if_not(isTRUE(active))
+    if (is.null(reporter$interrupt)) {
+      if (debug) mprintf("interrupt_reporter() ... skipping; not supported")
+      return()
+    }
+    do.call(reporter$interrupt, args = args)
+    .validate_internal_state("interrupt_reporter() ... done")
+    if (debug) mprintf("interrupt_reporter() ... done")
+  }
+
   finish_reporter <- function(p) {
     args <- reporter_args(progression = p)
     debug <- getOption("progressr.debug", FALSE)
@@ -256,7 +273,16 @@ make_progression_handler <- function(name, reporter = list(), handler = NULL, en
     if (active && !finished) {
       do.call(reporter$finish, args = args)
     } else {
-      if (debug) message("- Hmm ... got a request to 'finish' handler, but it's not active. Oh well, will finish it then")
+      if (debug) {
+        why <- if (!active && !finished) {
+          "not active"
+        } else if (!active && finished) {
+          "not active and already finished"
+        } else if (active && finished) {
+          "already finished"
+        }
+        message(sprintf("- Hmm ... got a request to 'finish' handler, but it's %s. Oh well, will finish it then", why))
+      }
     }
     
     reset_internal_state()
@@ -309,8 +335,11 @@ make_progression_handler <- function(name, reporter = list(), handler = NULL, en
         } else if (type == "unhide") {
           unhide_reporter(p)
           .validate_internal_state(sprintf("handler(type=%s) ... end", type))
+        } else if (type == "interrupt") {
+          interrupt_reporter(p)
+          .validate_internal_state(sprintf("handler(type=%s) ... end", type))
         } else {
-          stop("Unknown control_progression type: ", sQuote(type))
+          stop("Unknown 'control_progression' type: ", sQuote(type))
         }
         .validate_internal_state(sprintf("control_progression ... end", type))
         return(invisible(finished))
@@ -431,7 +460,12 @@ make_progression_handler <- function(name, reporter = list(), handler = NULL, en
         }
         .validate_internal_state(sprintf("handler(type=%s) ... end", type))
       } else {
-        stop("Unknown 'progression' type: ", sQuote(type))
+        ## Was this meant to be a 'control_progression' condition?
+        if (type %in% c("reset", "shutdown", "hide", "unhide", "interrupt")) {
+          stop("Unsupported 'progression' type. Was it meant to be a 'control_progression' condition?: ", sQuote(type))
+        } else {
+          stop("Unknown 'progression' type: ", sQuote(type))
+        }
       }
 
       ## Sanity checks
