@@ -17,26 +17,26 @@
 #' @keywords internal
 #' @export
 slow_sum <- function(x, delay = getOption("progressr.demo.delay", 1.0), stdout = FALSE, message = TRUE) {
-  progress <- progressor(along = x)
+  p <- progressor(along = x)
 
   sum <- 0
   for (kk in seq_along(x)) {
-    progress(amount = 0)   ## "I'm alive" progression update
+    p(amount = 0)   ## "I'm alive" progression update
     Sys.sleep(0.2*delay)
     if (stdout) cat(sprintf("O: Element #%d\n", kk))
-    progress(amount = 0)
+    p(amount = 0)
     Sys.sleep(0.2*delay)
-    progress(amount = 0)
+    p(amount = 0)
     Sys.sleep(0.2*delay)
     sum <- sum + x[kk]
-    progress(message = sprintf("P: Adding %g", kk))
+    p(message = sprintf("P: Adding %g", kk))
     Sys.sleep(0.2*delay)
     if (message) message(sprintf("M: Added value %g", x[kk]))
-    progress(amount = 0)
+    p(amount = 0)
     Sys.sleep(0.2*delay)
   }
 
-  progress(amount = 0)
+  p(amount = 0)
 
   sum
 }
